@@ -1,9 +1,13 @@
-#!/bin/bash
+#!/usr/bin/env bash
 
+. $(dirname "${BASH_SOURCE[0]}")/common.sh
 packname="0-init-fail-pack"
 deps="logger PACKAGE_DONT_EXIST" # would be very unlucky if it does exist...
 
-$DUB init -n $packname $deps -f json
+if $$DUB init -n $packname $deps -f json 2>/dev/null; then
+    die $LINENO 'Init with unknown non-existing dependency expected to fail'
+fi
+
 
 function cleanup {
     rm -rf $packname
@@ -11,6 +15,5 @@ function cleanup {
 
 if [ -e $packname/dub.json ]; then # package is there, it should have failed
     cleanup
-    exit 1
+    die $LINENO "$packname/dub.json was not created"
 fi
-exit 0
